vfbLib.parsers.mm.AnisotropicInterpolationsParser
=================================================

.. currentmodule:: vfbLib.parsers.mm

.. autoclass:: AnisotropicInterpolationsParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AnisotropicInterpolationsParser.__init__
      ~AnisotropicInterpolationsParser.parse
      ~AnisotropicInterpolationsParser.parse_hex
      ~AnisotropicInterpolationsParser.read_double
      ~AnisotropicInterpolationsParser.read_doubles
      ~AnisotropicInterpolationsParser.read_float
      ~AnisotropicInterpolationsParser.read_floats
      ~AnisotropicInterpolationsParser.read_int16
      ~AnisotropicInterpolationsParser.read_int32
      ~AnisotropicInterpolationsParser.read_int8
      ~AnisotropicInterpolationsParser.read_str
      ~AnisotropicInterpolationsParser.read_str_all
      ~AnisotropicInterpolationsParser.read_uint16
      ~AnisotropicInterpolationsParser.read_uint32
      ~AnisotropicInterpolationsParser.read_uint8
      ~AnisotropicInterpolationsParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AnisotropicInterpolationsParser.encoding
      ~AnisotropicInterpolationsParser.master_count
      ~AnisotropicInterpolationsParser.stream
      ~AnisotropicInterpolationsParser.ttStemsH_count
      ~AnisotropicInterpolationsParser.ttStemsV_count
   
   